@@ -33,7 +33,10 @@ describe 'placement::db::postgresql' do
         facts.merge!(OSDefaults.get_facts( :concat_basedir => '/var/lib/puppet/concat' ))
       end
 
-      it_behaves_like 'placement::db::postgresql'
+      # TODO(tkajinam): Remove this once puppet-postgresql supports CentOS 9
+      unless facts[:osfamily] == 'RedHat' and facts[:operatingsystemmajrelease].to_i >= 9
+        it_behaves_like 'placement::db::postgresql'
+      end
     end
   end
 end
